/*
 * Copyright (c) 2024 Oray Inc. All rights reserved.
 *
 * No Part of this file may be reproduced, stored
 * na retrieval system, or transmitted, in any form, or by any means,
 * electronic, mechanical, photocopying, recording, or otherwise,
 * without the prior consent of Oray Inc.
 *
 * @author wuwenze
 */

package sunapi

import (
	"sunlogin-api-example-golang/sunapi/dto"
	"testing"
)

var (
	controlCli *SunloginControlClient
	remoteCli  *SunloginRemoteClient
)

func init() {
	// 初始化授权客户端
	authCli := &SunloginAuthClient{
		Host:      "https://openapi.sunlogin.oray.com",
		ApiKey:    "<yourApiKey>",    // 参见：【系统设置】>【API集成】>【API KEY】
		ApiSecret: "<yourApiSecret>", // 参见：【系统设置】>【API集成】>【API KEY】
	}

	// 连接本地的向日葵主控端
	controlCli = NewSunloginControlClient("http://127.0.0.1:12138", authCli)

	// 连接本地的向日葵被控端
	remoteCli = NewSunloginRemoteClient("http://127.0.0.1:21238", authCli)
}

// TestSunloginControlClient_LaunchApp 测试调起主控客户端
func TestSunloginControlClient_LaunchApp(t *testing.T) {
	if err := controlCli.LaunchApp(); err != nil {
		t.Fatal(err)
	}
	t.Log("LaunchApp() successful")
}

// TestSunloginControlClient_IsAlive 测试检测主控端是否存活就绪
func TestSunloginControlClient_IsAlive(t *testing.T) {
	if err := controlCli.IsAlive(); err != nil {
		t.Fatal(err)
	}
	t.Log("IsAlive() successful")
}

// TestSunloginControlClient_LocateHost 测试定位到指定设备后，再发起远控
func TestSunloginControlClient_LocateHost(t *testing.T) {
	if err := controlCli.LocateHost(&dto.LocateHostRequest{
		RemoteId:    "1370395685",
		NeedControl: "1", // 1：定位到设备后发起远控，0：定位到设备后不发起远控
	}); err != nil {
		t.Fatal(err)
	}
	t.Log("LocateHost() successful")
}

// TestSunloginControlClient_RemoteControl 测试直接发起远控
func TestSunloginControlClient_RemoteControl(t *testing.T) {
	if err := controlCli.RemoteControl(&dto.RemoteControlRequest{
		RemoteId:   "",          // 设备ID
		Fastcode:   "567167xxx", // 设备识别码
		VerifyCode: "4p3xxx",    // 设备验证码
	}); err != nil {
		t.Fatal(err)
	}
	t.Log("RemoteControl() successful")
}

// TestSunloginRemoteClient_GetDeviceInfo 测试获取向日葵企业被控设备信息
func TestSunloginRemoteClient_GetDeviceInfo(t *testing.T) {
	deviceInfo, err := remoteCli.GetDeviceInfo()
	if err != nil {
		t.Fatal(err)
	}
	t.Logf("GetDeviceInfo result: %+v", deviceInfo)

	t.Logf("")
}