/*
 * Copyright (c) 2024 Oray Inc. All rights reserved.
 *
 * No Part of this file may be reproduced, stored
 * na retrieval system, or transmitted, in any form, or by any means,
 * electronic, mechanical, photocopying, recording, or otherwise,
 * without the prior consent of Oray Inc.
 *
 * @author wuwenze
 */

package sunapi

import (
	"log"
	"net/http"
	"net/http/httputil"
)

func NewHttpClient() *http.Client {
	return &http.Client{
		Transport: &loggingRoundTripper{
			Proxied: http.DefaultTransport,
		},
	}
}

// loggingRoundTripper 结构体实现了 http.RoundTripper 接口。
type loggingRoundTripper struct {
	Proxied http.RoundTripper
}

// RoundTrip 执行单个HTTP事务并记录请求和响应的详细信息。
func (lrt *loggingRoundTripper) RoundTrip(req *http.Request) (*http.Response, error) {
	log.SetPrefix("[HTTP]: ")
	log.SetFlags(log.Ldate | log.Ltime | log.Lshortfile)

	dumpRequest, _ := httputil.DumpRequest(req, true)
	resp, err := lrt.Proxied.RoundTrip(req)
	if err != nil {
		return nil, err
	}
	dumpResponse, _ := httputil.DumpResponse(resp, true)
	log.Printf("\n%s\n\n############ Response ############\n%s\n", dumpRequest, dumpResponse)
	return resp, nil
}